[libvirt] [PATCH 2/4] build: fix virdbus build on mingw

Eric Blake eblake at redhat.com
Mon Jul 29 14:53:36 UTC 2013


Mingw headers pollute the namespace.

  CC       libvirt_util_la-virdbus.lo
../../src/util/virdbus.c:1102:35: error: expected ';', ',' or ')' before 'struct'
                       const char *interface,
                                   ^

* src/util/virdbus.c (virDBusCallMethod): Avoid 'interface'.

Signed-off-by: Eric Blake <eblake at redhat.com>
---
 src/util/virdbus.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/util/virdbus.c b/src/util/virdbus.c
index 4ce6c46..8f724e9 100644
--- a/src/util/virdbus.c
+++ b/src/util/virdbus.c
@@ -982,13 +982,13 @@ int virDBusMessageDecode(DBusMessage* msg,
  * @replyout: pointer to receive reply message, or NULL
  * @destination: bus identifier of the target service
  * @path: object path of the target service
  * @interface: the interface of the object
  * @member: the name of the method in the interface
  * @types: type signature for following method arguments
  * @...: method arguments
  *
  * This invokes a method on a remote service on the
  * DBus bus @conn. The @destination, @path, @interface
  * and @member parameters identify the object method to
  * be invoked. The optional @replyout parameter will be
  * filled with any reply to the method call. The
@@ -1099,7 +1099,7 @@ int virDBusCallMethod(DBusConnection *conn,
                       DBusMessage **replyout,
                       const char *destination,
                       const char *path,
-                      const char *interface,
+                      const char *iface,
                       const char *member,
                       const char *types, ...)
 {
@@ -1113,7 +1113,7 @@ int virDBusCallMethod(DBusConnection *conn,

     if (!(call = dbus_message_new_method_call(destination,
                                               path,
-                                              interface,
+                                              iface,
                                               member))) {
         virReportOOMError();
         goto cleanup;
@@ -1206,7 +1206,7 @@ int virDBusCallMethod(DBusConnection *conn ATTRIBUTE_UNUSED,
                       DBusMessage **reply ATTRIBUTE_UNUSED,
                       const char *destination ATTRIBUTE_UNUSED,
                       const char *path ATTRIBUTE_UNUSED,
-                      const char *interface ATTRIBUTE_UNUSED,
+                      const char *iface ATTRIBUTE_UNUSED,
                       const char *member ATTRIBUTE_UNUSED,
                       const char *types ATTRIBUTE_UNUSED, ...)
 {
@@ -982,13 +982,13 @@ int virDBusMessageDecode(DBusMessage* msg,
  * @destination: bus identifier of the target service
  * @path: object path of the target service
- * @interface: the interface of the object
+ * @iface: the interface of the object
  * @member: the name of the method in the interface
  * @types: type signature for following method arguments
@@ -982,13 +982,13 @@ int virDBusMessageDecode(DBusMessage* msg,
  *
  * This invokes a method on a remote service on the
- * DBus bus @conn. The @destination, @path, @interface
+ * DBus bus @conn. The @destination, @path, @iface
  * and @member parameters identify the object method to
  * be invoked. The optional @replyout parameter will be
-- 
1.8.3.1




More information about the libvir-list mailing list